#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_MAP_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_MAP_HPP_INCLUDED

#include <boost/simd/operator/include/functions/simd/map.hpp>

#endif
